==> phaser-3.24.1.jar: META-INF/resources/webjars/phaser/3.24.1/src/geom/intersects/index.js <==
/**
 * @author       Richard Davey <rich@photonstorm.com>
 * @copyright    2020 Photon Storm Ltd.
 * @license      {@link https://opensource.org/licenses/MIT|MIT License}
 */

/**
 * @namespace Phaser.Geom.Intersects
 */

module.exports = {

    CircleToCircle: require('./CircleToCircle'),
    CircleToRectangle: require('./CircleToRectangle'),
    GetCircleToCircle: require('./GetCircleToCircle'),
    GetCircleToRectangle: require('./GetCircleToRectangle'),
    GetLineToCircle: require('./GetLineToCircle'),
    GetLineToRectangle: require('./GetLineToRectangle'),
    GetRectangleIntersection: require('./GetRectangleIntersection'),
    GetRectangleToRectangle: require('./GetRectangleToRectangle'),
    GetRectangleToTriangle: require('./GetRectangleToTriangle'),
    GetTriangleToCircle: require('./GetTriangleToCircle'),
    GetTriangleToLine: require('./GetTriangleToLine'),
    GetTriangleToTriangle: require('./GetTriangleToTriangle'),
    LineToCircle: require('./LineToCircle'),
    LineToLine: require('./LineToLine'),
    LineToRectangle: require('./LineToRectangle'),
    PointToLine: require('./PointToLine'),
    PointToLineSegment: require('./PointToLineSegment'),
    RectangleToRectangle: require('./RectangleToRectangle'),
    RectangleToTriangle: require('./RectangleToTriangle'),
    RectangleToValues: require('./RectangleToValues'),
    TriangleToCircle: require('./TriangleToCircle'),
    TriangleToLine: require('./TriangleToLine'),
    TriangleToTriangle: require('./TriangleToTriangle')

};

==> phaser-3.55.2.jar: META-INF/resources/webjars/phaser/3.55.2/src/geom/intersects/index.js <==
/**
 * @author       Richard Davey <rich@photonstorm.com>
 * @copyright    2020 Photon Storm Ltd.
 * @license      {@link https://opensource.org/licenses/MIT|MIT License}
 */

/**
 * @namespace Phaser.Geom.Intersects
 */

module.exports = {

    CircleToCircle: require('./CircleToCircle'),
    CircleToRectangle: require('./CircleToRectangle'),
    GetCircleToCircle: require('./GetCircleToCircle'),
    GetCircleToRectangle: require('./GetCircleToRectangle'),
    GetLineToCircle: require('./GetLineToCircle'),
    GetLineToLine: require('./GetLineToLine'),
    GetLineToPoints: require('./GetLineToPoints'),
    GetLineToPolygon: require('./GetLineToPolygon'),
    GetLineToRectangle: require('./GetLineToRectangle'),
    GetRaysFromPointToPolygon: require('./GetRaysFromPointToPolygon'),
    GetRectangleIntersection: require('./GetRectangleIntersection'),
    GetRectangleToRectangle: require('./GetRectangleToRectangle'),
    GetRectangleToTriangle: require('./GetRectangleToTriangle'),
    GetTriangleToCircle: require('./GetTriangleToCircle'),
    GetTriangleToLine: require('./GetTriangleToLine'),
    GetTriangleToTriangle: require('./GetTriangleToTriangle'),
    LineToCircle: require('./LineToCircle'),
    LineToLine: require('./LineToLine'),
    LineToRectangle: require('./LineToRectangle'),
    PointToLine: require('./PointToLine'),
    PointToLineSegment: require('./PointToLineSegment'),
    RectangleToRectangle: require('./RectangleToRectangle'),
    RectangleToTriangle: require('./RectangleToTriangle'),
    RectangleToValues: require('./RectangleToValues'),
    TriangleToCircle: require('./TriangleToCircle'),
    TriangleToLine: require('./TriangleToLine'),
    TriangleToTriangle: require('./TriangleToTriangle')

};
